https://svn.lrde.epita.fr/svn/oln/trunk/milena
Index: ChangeLog
from Roland Levillain <roland(a)lrde.epita.fr>
Have tools compile again.
* tools/seed2tiling.cc: Don't include mln/draw/mesh.hh.
* mln/make/voronoi.hh: s/mln::mesh_p/p_graph/.
* mln/core/ops.hh: Add a FIXME about a warning on an uninitialized
value.
mln/core/ops.hh | 2 ++
mln/make/voronoi.hh | 12 ++++++------
tools/seed2tiling.cc | 1 -
3 files changed, 8 insertions(+), 7 deletions(-)
Index: tools/seed2tiling.cc
--- tools/seed2tiling.cc (revision 1943)
+++ tools/seed2tiling.cc (working copy)
@@ -42,7 +42,6 @@
# include <mln/io/pgm/save.hh>
# include <mln/labeling/foreground.hh>
# include <mln/debug/println.hh>
-# include <mln/draw/mesh.hh>
# include <mln/geom/seeds2tiling.hh>
# include <mln/geom/seeds2tiling_roundness.hh>
# include <mln/make/voronoi.hh>
Index: mln/core/ops.hh
--- mln/core/ops.hh (revision 1943)
+++ mln/core/ops.hh (working copy)
@@ -413,6 +413,8 @@
operator-(const Object<O>& rhs)
{
mlc_converts_to(literal::zero_t, O)::check();
+ /* FIXME: The following statements trigger a warning:
+ ``'p_zero' is used uninitialized in this function.'' */
literal::zero_t* p_zero;
return O(*p_zero) - exact(rhs);
}
Index: mln/make/voronoi.hh
--- mln/make/voronoi.hh (revision 1943)
+++ mln/make/voronoi.hh (working copy)
@@ -1,4 +1,4 @@
-// Copyright (C) 2007 EPITA Research and Development Laboratory
+// Copyright (C) 2007, 2008 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of the Olena Library. This library is free
// software; you can redistribute it and/or modify it under the terms
@@ -30,14 +30,14 @@
/*! \file mln/make/voronoi.hh
*
* \brief Routine to construct a voronoi mln::mesh_p.
*/
# include <vector>
# include <map>
# include <mln/core/concept/neighborhood.hh>
-# include <mln/core/mesh_p.hh>
+# include <mln/core/p_graph.hh>
# include <mln/accu/mean.hh>
# include <mln/estim/min_max.hh>
@@ -58,7 +58,7 @@
* \return The computed graph.
*/
template <typename I, typename N>
- mesh_p<mln_psite(I)>
+ p_graph<mln_psite(I)>
voronoi (Image<I>& ima_,
Image<I>& orig_,
const Neighborhood<N>& nbh);
@@ -67,7 +67,7 @@
template <typename I, typename N>
inline
- mesh_p<mln_psite(I)>
+ p_graph<mln_psite(I)>
voronoi (Image<I>& ima_,
Image<I>& orig_,
const Neighborhood<N>& nbh)
@@ -127,7 +127,7 @@
for (; it != m.end (); ++it)
gr.add_edge((*it).first.first, (*it).first.second);
- mesh_p<P> res(gr, v);
+ p_graph<P> res(gr, v);
return res;
}
@@ -30,14 +30,14 @@
/*! \file mln/make/voronoi.hh
*
- * \brief Routine to construct a voronoi mln::mesh_p.
+ * \brief Routine to construct a Voronoi mln::p_graph.
*/
# include <vector>